Changelog
=========

.. currentmodule:: hancock

Release 0.1b0
-------------

*Update* - Beta release, added params to get, post, put, delete, request functions for timeout and verify_ssl


Release 0.1a0
-------------

Initial release
